@@ -5,6 +5,7 @@ import com.unciv.logic.city.City
 import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.Spy
+import com.unciv.models.ruleset.unique.UniqueType
 
 
 class EspionageManager : IsPartOfGameInfoSerialization {
@@ -15,6 +16,13 @@ class EspionageManager : IsPartOfGameInfoSerialization {
     @Transient
     lateinit var civInfo: Civilization
 
+    /**
+     * Part of the nextTurnAction of MoveSpies.
+     * We need to store if the player has clicked the button already
+     */
+    @Transient
+    var dismissedShouldMoveSpies = false
+
     fun clone(): EspionageManager {
         val toReturn = EspionageManager()
         spyList.mapTo(toReturn.spyList) { it.clone() }
@@ -41,12 +49,12 @@ class EspionageManager : IsPartOfGameInfoSerialization {
         return validSpyNames.random()
     }
 
-    fun addSpy(): String {
+    fun addSpy(): Spy {
         val spyName = getSpyName()
-        val newSpy = Spy(spyName)
+        val newSpy = Spy(spyName, getStartingSpyRank())
         newSpy.setTransients(civInfo)
         spyList.add(newSpy)
-        return spyName
+        return newSpy
     }
 
     fun getTilesVisibleViaSpies(): Sequence<Tile> {
@@ -70,5 +78,19 @@ class EspionageManager : IsPartOfGameInfoSerialization {
         return spyList.filter { it.getLocation() == city }.toMutableList()
     }
 
+    fun getStartingSpyRank(): Int = 1 + civInfo.getMatchingUniques(UniqueType.SpyStartingLevel).sumOf { it.params[0].toInt() }
+
+    /**
+     * Returns a list of all cities with our spies in them.
+     * The list needs to be stable accross calls on the same turn.
+     */
+    fun getCitiesWithOurSpies(): List<City> = spyList.filter { it.isSetUp() }.mapNotNull { it.getLocation() }
+
     fun getSpyAssignedToCity(city: City): Spy? = spyList.firstOrNull {it.getLocation() == city}
+
+    /**
+     * Determines whether the NextTurnAction MoveSpies should be shown or not
+     * @return true if there are spies waiting to be moved
+     */
+    fun shouldShowMoveSpies(): Boolean = !dismissedShouldMoveSpies && spyList.any { it.isIdle() }
 }
