@@ -12,12 +12,6 @@ interface MultiplayerGameUpdateSucceeded : Event, HasMultiplayerGameName {
     val preview: GameInfoPreview
 }
 
-/**
- * Gets sent when a game was added.
- */
-class MultiplayerGameAdded(
-    override val name: String
-) : Event, HasMultiplayerGameName
 /**
  * Gets sent when a game successfully updated
  */
@@ -55,10 +49,3 @@ class MultiplayerGameNameChanged(
     override val name: String,
     val newName: String
 ) : Event, HasMultiplayerGameName
-
-/**
- * Gets sent when a game is deleted
- */
-class MultiplayerGameDeleted(
-    override val name: String
-) : Event, HasMultiplayerGameName
