@@ -1,6 +1,7 @@
 package com.unciv.models.ruleset
 
 import com.unciv.Constants
+import com.unciv.logic.GameInfo
 import com.unciv.logic.MultiFilter
 import com.unciv.logic.city.City
 import com.unciv.logic.city.CityConstructions
@@ -64,6 +65,18 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
     fun getDescription(city: City, showAdditionalInfo: Boolean) = BuildingDescriptions.getDescription(this, city, showAdditionalInfo)
     override fun getCivilopediaTextLines(ruleset: Ruleset) = BuildingDescriptions.getCivilopediaTextLines(this, ruleset)
 
+    override fun isHiddenBySettings(gameInfo: GameInfo): Boolean {
+        if (super<INonPerpetualConstruction>.isHiddenBySettings(gameInfo)) return true
+        if (!gameInfo.gameParameters.nuclearWeaponsEnabled && hasUnique(UniqueType.EnablesNuclearWeapons)) return true
+        return isHiddenByStartingEra(gameInfo)
+    }
+    private fun isHiddenByStartingEra(gameInfo: GameInfo): Boolean {
+        if (!isWonder) return false
+        // do not rely on this.ruleset or unit tests break
+        val startingEra = gameInfo.ruleset.eras[gameInfo.gameParameters.startingEra] ?: return false
+        return name in startingEra.startingObsoleteWonders
+    }
+
     fun getStats(city: City,
                  /* By default, do not cache - if we're getting stats for only one building this isn't efficient.
                  * Only use a cache if it was sent to us from outside, which means we can use the results for other buildings.  */
@@ -121,7 +134,7 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
 
         if (civInfo.isCityState())
             productionCost *= 1.5f
-        if (civInfo.isHuman()) {
+        else if (civInfo.isHuman()) {
             if (!isWonder)
                 productionCost *= civInfo.getDifficulty().buildingCostModifier
         } else {
@@ -252,6 +265,14 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
         if (cityConstructions.isBuilt(name))
             yield(RejectionReasonType.AlreadyBuilt.toInstance())
 
+        if (isHiddenBySettings(civ.gameInfo)) {
+            // Repeat the starting era test isHiddenBySettings already did to change the RejectionReasonType
+            if (isHiddenByStartingEra(civ.gameInfo))
+                yield(RejectionReasonType.WonderDisabledEra.toInstance())
+            else
+                yield(RejectionReasonType.DisabledBySetting.toInstance())
+        }
+
         for (unique in uniqueObjects) {
             // skip uniques that don't have conditionals apply
             // EXCEPT for [UniqueType.OnlyAvailable] and [UniqueType.CanOnlyBeBuiltInCertainCities]
@@ -259,7 +280,6 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
             if (unique.type != UniqueType.OnlyAvailable && unique.type != UniqueType.CanOnlyBeBuiltWhen &&
                 !unique.conditionalsApply(StateForConditionals(civ, cityConstructions.city))) continue
 
-            @Suppress("NON_EXHAUSTIVE_WHEN")
             when (unique.type) {
                 // for buildings that are created as side effects of other things, and not directly built,
                 // or for buildings that can only be bought
@@ -279,9 +299,6 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                     if (unique.params[0].toInt() > cityConstructions.city.population.population)
                         yield(RejectionReasonType.PopulationRequirement.toInstance(unique.text))
 
-                UniqueType.EnablesNuclearWeapons -> if (!cityConstructions.city.civ.gameInfo.gameParameters.nuclearWeaponsEnabled)
-                    yield(RejectionReasonType.DisabledBySetting.toInstance())
-
                 UniqueType.MustBeOn ->
                     if (!cityCenter.matchesTerrainFilter(unique.params[0], civ))
                         yield(RejectionReasonType.MustBeOnTile.toInstance(unique.text))
@@ -312,10 +329,6 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                     if (civ.tech.isResearched(unique.params[0]))
                         yield(RejectionReasonType.Obsoleted.toInstance(unique.text))
 
-                UniqueType.HiddenWithoutReligion ->
-                    if (!civ.gameInfo.isReligionEnabled())
-                        yield(RejectionReasonType.DisabledBySetting.toInstance())
-
                 UniqueType.MaxNumberBuildable ->
                     if (civ.civConstructions.countConstructedObjects(this@Building) >= unique.params[0].toInt())
                         yield(RejectionReasonType.MaxNumberBuildable.toInstance())
@@ -366,11 +379,6 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
                         yield(RejectionReasonType.MorePolicyBranches.toInstance(unique.text))
                 }
 
-                UniqueType.HiddenWithoutVictoryType -> {
-                    if (!civ.gameInfo.gameParameters.victoryTypes.contains(unique.params[0]))
-                        yield(RejectionReasonType.HiddenWithoutVictory.toInstance(unique.text))
-                }
-
                 else -> {}
             }
         }
@@ -385,32 +393,28 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
             if (!civ.tech.isResearched(requiredTech))
                 yield(RejectionReasonType.RequiresTech.toInstance("$requiredTech not researched!"))
 
-        // Regular wonders
-        if (isWonder) {
-            if (civ.gameInfo.getCities().any { it.cityConstructions.isBuilt(name) })
-                yield(RejectionReasonType.WonderAlreadyBuilt.toInstance())
-
+        // All Wonders
+        if(isAnyWonder()) {
             if (civ.cities.any { it != cityConstructions.city && it.cityConstructions.isBeingConstructedOrEnqueued(name) })
                 yield(RejectionReasonType.WonderBeingBuiltElsewhere.toInstance())
 
             if (civ.isCityState())
                 yield(RejectionReasonType.CityStateWonder.toInstance())
 
-            val startingEra = civ.gameInfo.gameParameters.startingEra
-            if (name in ruleSet.eras[startingEra]!!.startingObsoleteWonders)
-                yield(RejectionReasonType.WonderDisabledEra.toInstance())
+            if (cityConstructions.city.isPuppet)
+                yield(RejectionReasonType.PuppetWonder.toInstance())
         }
 
-        // National wonders
+        // World Wonders
+        if (isWonder) {
+            if (civ.gameInfo.getCities().any { it.cityConstructions.isBuilt(name) })
+                yield(RejectionReasonType.WonderAlreadyBuilt.toInstance())
+        }
+
+        // National Wonders
         if (isNationalWonder) {
             if (civ.cities.any { it.cityConstructions.isBuilt(name) })
                 yield(RejectionReasonType.NationalWonderAlreadyBuilt.toInstance())
-
-            if (civ.cities.any { it != cityConstructions.city && it.cityConstructions.isBeingConstructedOrEnqueued(name) })
-                yield(RejectionReasonType.NationalWonderBeingBuiltElsewhere.toInstance())
-
-            if (civ.isCityState())
-                yield(RejectionReasonType.CityStateNationalWonder.toInstance())
         }
 
         if (requiredBuilding != null && !cityConstructions.containsBuildingOrEquivalent(requiredBuilding!!)) {
@@ -501,9 +505,16 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
         return true
     }
 
+
+    private val cachedMatchesFilterResult = HashMap<String, Boolean>()
+
     /** Implements [UniqueParameterType.BuildingFilter] */
     fun matchesFilter(filter: String): Boolean {
-        return MultiFilter.multiFilter(filter, ::matchesSingleFilter)
+        val cachedAnswer = cachedMatchesFilterResult[filter]
+        if (cachedAnswer != null) return cachedAnswer
+        val newAnswer = MultiFilter.multiFilter(filter, { matchesSingleFilter(it) })
+        cachedMatchesFilterResult[filter] = newAnswer
+        return newAnswer
     }
 
     private fun matchesSingleFilter(filter: String): Boolean {
@@ -542,7 +553,7 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
     fun hasCreateOneImprovementUnique() = _hasCreatesOneImprovementUnique
 
     private var _getImprovementToCreate: TileImprovement? = null
-    fun getImprovementToCreate(ruleset: Ruleset): TileImprovement? {
+    private fun getImprovementToCreate(ruleset: Ruleset): TileImprovement? {
         if (!hasCreateOneImprovementUnique()) return null
         if (_getImprovementToCreate == null) {
             val improvementUnique = getMatchingUniques(UniqueType.CreatesOneImprovement)
@@ -551,6 +562,10 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
         }
         return _getImprovementToCreate
     }
+    fun getImprovementToCreate(ruleset: Ruleset, civInfo: Civilization): TileImprovement? {
+        val improvement = getImprovementToCreate(ruleset) ?: return null
+        return civInfo.getEquivalentTileImprovement(improvement)
+    }
 
     fun isSellable() = !isAnyWonder() && !hasUnique(UniqueType.Unsellable)
 
@@ -561,12 +576,4 @@ class Building : RulesetStatsObject(), INonPerpetualConstruction {
             resourceRequirements[unique.params[1]] += unique.params[0].toInt()
         return resourceRequirements
     }
-
-    override fun requiresResource(resource: String, stateForConditionals: StateForConditionals?): Boolean {
-        if (getResourceRequirementsPerTurn(stateForConditionals).contains(resource)) return true
-        for (unique in getMatchingUniques(UniqueType.CostsResources, stateForConditionals)) {
-            if (unique.params[1] == resource) return true
-        }
-        return false
-    }
 }
