@@ -1,5 +1,7 @@
 package com.unciv.models.ruleset
 
+import com.unciv.Constants
+import com.unciv.logic.MultiFilter
 import com.unciv.models.ruleset.unique.StateForConditionals
 import com.unciv.models.ruleset.unique.UniqueTarget
 import com.unciv.models.ruleset.unique.UniqueType
@@ -33,6 +35,19 @@ open class Policy : RulesetObject() {
         fun isBranchCompleteByName(name: String) = name.endsWith(branchCompleteSuffix)
     }
 
+    fun matchesFilter(filter: String): Boolean {
+        return MultiFilter.multiFilter(filter, ::matchesSingleFilter)
+    }
+    fun matchesSingleFilter(filter: String): Boolean {
+        return when(filter) {
+            in Constants.all -> true
+            name -> true
+            "[${branch.name}] branch" -> true
+            in uniques -> true
+            else -> false
+        }
+    }
+
     /** Used in PolicyPickerScreen to display Policy properties */
     fun getDescription(): String {
         return (if (policyBranchType == PolicyBranchType.Member) name.tr() + "\n" else "") +
