@@ -13,8 +13,8 @@ import com.unciv.models.translations.tr
 import com.unciv.ui.components.extensions.colorFromRGB
 import com.unciv.ui.objectdescriptions.BaseUnitDescriptions
 import com.unciv.ui.objectdescriptions.BuildingDescriptions
+import com.unciv.ui.objectdescriptions.ImprovementDescriptions
 import com.unciv.ui.objectdescriptions.uniquesToCivilopediaTextLines
-import com.unciv.ui.screens.civilopediascreen.CivilopediaScreen.Companion.showReligionInCivilopedia
 import com.unciv.ui.screens.civilopediascreen.FormattedLine
 import kotlin.math.pow
 
@@ -191,38 +191,34 @@ class Nation : RulesetObject() {
     }
 
     private fun getUniqueBuildingsText(ruleset: Ruleset) = sequence {
-        val religionEnabled = showReligionInCivilopedia(ruleset)
         for (building in ruleset.buildings.values) {
-            when {
-                building.uniqueTo != name -> continue
-                building.hasUnique(UniqueType.HiddenFromCivilopedia) -> continue
-                !religionEnabled && building.hasUnique(UniqueType.HiddenWithoutReligion) -> continue
-            }
+            if (building.uniqueTo != name) continue
+            if (building.isHiddenFromCivilopedia(ruleset)) continue
             yield(FormattedLine(separator = true))
-            yield(FormattedLine("{${building.name}} -", link=building.makeLink()))
+            yield(FormattedLine("{${building.name}} -", link = building.makeLink()))
             if (building.replaces != null && ruleset.buildings.containsKey(building.replaces!!)) {
                 val originalBuilding = ruleset.buildings[building.replaces!!]!!
-                yield(FormattedLine("Replaces [${originalBuilding.name}]", link = originalBuilding.makeLink(), indent=1))
+                yield(FormattedLine("Replaces [${originalBuilding.name}]", link = originalBuilding.makeLink(), indent = 1))
                 yieldAll(BuildingDescriptions.getDifferences(ruleset, originalBuilding, building))
                 yield(FormattedLine())
             } else if (building.replaces != null) {
-                yield(FormattedLine("Replaces [${building.replaces}], which is not found in the ruleset!", indent=1))
+                yield(FormattedLine("Replaces [${building.replaces}], which is not found in the ruleset!", indent = 1))
             } else {
-                yield(FormattedLine(building.getShortDescription(true), indent=1))
+                yield(FormattedLine(building.getShortDescription(true), indent = 1))
             }
         }
     }
 
     private fun getUniqueUnitsText(ruleset: Ruleset) = sequence {
         for (unit in ruleset.units.values) {
-            if (unit.uniqueTo != name || unit.hasUnique(UniqueType.HiddenFromCivilopedia)) continue
+            if (unit.uniqueTo != name || unit.isHiddenFromCivilopedia(ruleset)) continue
             yield(FormattedLine(separator = true))
-            yield(FormattedLine("{${unit.name}} -", link="Unit/${unit.name}"))
+            yield(FormattedLine("{${unit.name}} -", link = "Unit/${unit.name}"))
             if (unit.replaces != null && ruleset.units.containsKey(unit.replaces!!)) {
                 val originalUnit = ruleset.units[unit.replaces!!]!!
-                yield(FormattedLine("Replaces [${originalUnit.name}]", link="Unit/${originalUnit.name}", indent=1))
+                yield(FormattedLine("Replaces [${originalUnit.name}]", link = "Unit/${originalUnit.name}", indent = 1))
                 if (unit.cost != originalUnit.cost)
-                    yield(FormattedLine("{Cost} ".tr() + "[${unit.cost}] vs [${originalUnit.cost}]".tr(), indent=1))
+                    yield(FormattedLine("{Cost} ".tr() + "[${unit.cost}] vs [${originalUnit.cost}]".tr(), indent = 1))
                 yieldAll(
                     BaseUnitDescriptions.getDifferences(ruleset, originalUnit, unit)
                     .map { (text, link) -> FormattedLine(text, link = link ?: "", indent = 1) }
@@ -241,22 +237,20 @@ class Nation : RulesetObject() {
 
     private fun getUniqueImprovementsText(ruleset: Ruleset) = sequence {
         for (improvement in ruleset.tileImprovements.values) {
-            if (improvement.uniqueTo != name || improvement.hasUnique(UniqueType.HiddenFromCivilopedia)) continue
+            if (improvement.uniqueTo != name || improvement.isHiddenFromCivilopedia(ruleset)) continue
 
             yield(FormattedLine(separator = true))
             yield(FormattedLine(improvement.name, link = "Improvement/${improvement.name}"))
             yield(FormattedLine(improvement.cloneStats().toString(), indent = 1))   // = (improvement as Stats).toString minus import plus copy overhead
-            if (improvement.terrainsCanBeBuiltOn.isNotEmpty()) {
-                improvement.terrainsCanBeBuiltOn.withIndex().forEach {
-                    yield(
-                        FormattedLine(if (it.index == 0) "{Can be built on} {${it.value}}" else "or [${it.value}]",
-                        link = "Terrain/${it.value}", indent = if (it.index == 0) 1 else 2)
-                    )
-                }
-            }
-            for (unique in improvement.uniqueObjects) {
-                if (unique.isHiddenToUsers()) continue
-                yield(FormattedLine(unique, indent = 1))
+            if (improvement.replaces != null && ruleset.tileImprovements.containsKey(improvement.replaces!!)) {
+                val originalImprovement = ruleset.tileImprovements[improvement.replaces!!]!!
+                yield(FormattedLine("Replaces [${originalImprovement.name}]", link = originalImprovement.makeLink(), indent = 1))
+                yieldAll(ImprovementDescriptions.getDifferences(ruleset, originalImprovement, improvement))
+                yield(FormattedLine())
+            } else if (improvement.replaces != null) {
+                yield(FormattedLine("Replaces [${improvement.replaces}], which is not found in the ruleset!", indent = 1))
+            } else {
+                yieldAll(improvement.getShortDecription())
             }
         }
     }
