@@ -8,6 +8,7 @@ import com.unciv.GUI
 import com.unciv.UncivGame
 import com.unciv.logic.automation.Automation
 import com.unciv.logic.city.City
+import com.unciv.logic.civilization.Civilization
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.TutorialTrigger
 import com.unciv.models.UncivSound
@@ -60,8 +61,19 @@ class CityScreen(
         const val wltkIconSize = 40f
     }
 
+    private val selectedCiv: Civilization = GUI.getWorldScreen().selectedCiv
+
+    private val isSpying = selectedCiv.gameInfo.isEspionageEnabled() && selectedCiv != city.civ
+
+    /**
+     * This is the regular civ city list if we are not spying, if we are spying then it is every foreign city that our spies are in
+     */
+    val viewableCities = if (isSpying) selectedCiv.espionageManager.getCitiesWithOurSpies()
+        .filter { it.civ !=  GUI.getWorldScreen().selectedCiv }
+    else city.civ.cities
+
     /** Toggles or adds/removes all state changing buttons */
-    val canChangeState = GUI.isAllowedChangeState()
+    val canChangeState = GUI.isAllowedChangeState() && !isSpying
 
     // Clockwise from the top-left
 
@@ -136,6 +148,7 @@ class CityScreen(
 
         //stage.setDebugTableUnderMouse(true)
         stage.addActor(cityStatsTable)
+        // If we are spying then we shoulden't be able to see their construction screen.
         constructionsTable.addActorsToStage()
         stage.addActor(selectedConstructionTable)
         stage.addActor(tileTable)
@@ -151,7 +164,7 @@ class CityScreen(
         // Recalculate Stats
         city.cityStats.update()
 
-        constructionsTable.isVisible = true
+        constructionsTable.isVisible = !isSpying
         constructionsTable.update(selectedConstruction)
 
         updateWithoutConstructionAndMap()
@@ -313,7 +326,7 @@ class CityScreen(
     private fun addTiles() {
         val tileSetStrings = TileSetStrings()
         val cityTileGroups = city.getCenterTile().getTilesInDistance(5)
-                .filter { city.civ.hasExplored(it) }
+                .filter { selectedCiv.hasExplored(it) }
                 .map { CityTileGroup(city, it, tileSetStrings) }
 
         for (tileGroup in cityTileGroups) {
@@ -454,7 +467,7 @@ class CityScreen(
     fun selectConstruction(newConstruction: IConstruction) {
         selectedConstruction = newConstruction
         if (newConstruction is Building && newConstruction.hasCreateOneImprovementUnique()) {
-            val improvement = newConstruction.getImprovementToCreate(city.getRuleset())
+            val improvement = newConstruction.getImprovementToCreate(city.getRuleset(), city.civ)
             selectedQueueEntryTargetTile = if (improvement == null) null
                 else city.cityConstructions.getTileForImprovement(improvement.name)
         } else {
@@ -472,7 +485,7 @@ class CityScreen(
     fun clearSelection() = selectTile(null)
 
     fun startPickTileForCreatesOneImprovement(construction: Building, stat: Stat, isBuying: Boolean) {
-        val improvement = construction.getImprovementToCreate(city.getRuleset()) ?: return
+        val improvement = construction.getImprovementToCreate(city.getRuleset(), city.civ) ?: return
         pickTileData = PickTileForImprovementData(construction, improvement, isBuying, stat)
         updateTileGroups()
         ToastPopup("Please select a tile for this building's [${improvement.name}]", this)
@@ -501,12 +514,11 @@ class CityScreen(
         // Normal order is create new, then dispose old. But CityAmbiencePlayer delegates to a single instance of MusicController,
         // leading to one extra play followed by a stop for the city ambience sounds. To avoid that, we pass our player on and relinquish control.
 
-        val civInfo = city.civ
-        val numCities = civInfo.cities.size
+        val numCities = viewableCities.size
         if (numCities == 0) return
-        val indexOfCity = civInfo.cities.indexOf(city)
+        val indexOfCity = viewableCities.indexOf(city)
         val indexOfNextCity = (indexOfCity + delta + numCities) % numCities
-        val newCityScreen = CityScreen(civInfo.cities[indexOfNextCity], ambiencePlayer = passOnCityAmbiencePlayer())
+        val newCityScreen = CityScreen(viewableCities[indexOfNextCity], ambiencePlayer = passOnCityAmbiencePlayer())
         newCityScreen.update()
         game.replaceCurrentScreen(newCityScreen)
     }
