@@ -11,6 +11,8 @@ import com.unciv.UncivGame
 import com.unciv.logic.city.City
 import com.unciv.logic.city.CityFlags
 import com.unciv.logic.city.CityFocus
+import com.unciv.logic.city.CityResources
+import com.unciv.logic.city.GreatPersonPointsBreakdown
 import com.unciv.models.Counter
 import com.unciv.models.ruleset.Building
 import com.unciv.models.ruleset.tile.TileResource
@@ -182,7 +184,8 @@ class CityStatsTable(private val cityScreen: CityScreen) : Table() {
         val resourceTable = Table()
 
         val resourceCounter = Counter<TileResource>()
-        for (resourceSupply in city.getCityResources()) resourceCounter.add(resourceSupply.resource, resourceSupply.amount)
+        for (resourceSupply in CityResources.getCityResourcesAvailableToCity(city))
+            resourceCounter.add(resourceSupply.resource, resourceSupply.amount)
         for ((resource, amount) in resourceCounter)
             if (resource.hasUnique(UniqueType.CityResource)) {
                 resourceTable.add(amount.toLabel())
@@ -350,21 +353,14 @@ class CityStatsTable(private val cityScreen: CityScreen) : Table() {
 
         val greatPeopleTable = Table()
 
-        val greatPersonPoints = city.getGreatPersonPointsForNextTurn()
-        val allGreatPersonNames = greatPersonPoints.asSequence().flatMap { it.value.keys }.distinct()
-
-        if (allGreatPersonNames.none())
+        val gppBreakdown = GreatPersonPointsBreakdown(city)
+        if (gppBreakdown.allNames.isEmpty())
             return
+        val greatPersonPoints = gppBreakdown.sum()
 
-        for (greatPersonName in allGreatPersonNames) {
-
-            var gppPerTurn = 0
-
-            for ((_, gppCounter) in greatPersonPoints) {
-                val gppPointsFromSource = gppCounter[greatPersonName]
-                if (gppPointsFromSource == 0) continue
-                gppPerTurn += gppPointsFromSource
-            }
+        // Iterating over allNames instead of greatPersonPoints will include those where the aggregation had points but ended up zero
+        for (greatPersonName in gppBreakdown.allNames) {
+            val gppPerTurn = greatPersonPoints[greatPersonName]
 
             val info = Table()
 
@@ -391,9 +387,15 @@ class CityStatsTable(private val cityScreen: CityScreen) : Table() {
             progressBar.setLabel(Color.WHITE, "$gppCurrent/$gppNeeded", fontSize = 14)
 
             info.add(progressBar).colspan(2).left().expandX().row()
-
+            info.onClick {
+                GreatPersonPointsBreakdownPopup(cityScreen, gppBreakdown, greatPersonName)
+            }
             greatPeopleTable.add(info).growX().top().padBottom(10f)
-            greatPeopleTable.add(ImageGetter.getConstructionPortrait(greatPersonName, 50f)).row()
+            val icon = ImageGetter.getConstructionPortrait(greatPersonName, 50f)
+            icon.onClick {
+                GreatPersonPointsBreakdownPopup(cityScreen, gppBreakdown, null)
+            }
+            greatPeopleTable.add(icon).row()
         }
 
         lowerTable.addCategory("Great People", greatPeopleTable, KeyboardBinding.GreatPeopleDetail)
