@@ -18,12 +18,15 @@ import com.unciv.logic.map.MapSizeNew
 import com.unciv.logic.map.TileMap
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.metadata.BaseRuleset
+import com.unciv.models.metadata.GameParameters
 import com.unciv.models.metadata.GameSetupInfo
 import com.unciv.models.ruleset.Ruleset
 import com.unciv.models.ruleset.RulesetCache
+import com.unciv.ui.components.UncivTextField
 import com.unciv.ui.components.input.KeyCharAndCode
 import com.unciv.ui.components.input.KeyShortcutDispatcherVeto
 import com.unciv.ui.components.input.KeyboardPanningListener
+import com.unciv.ui.components.input.onChange
 import com.unciv.ui.components.tilegroups.TileGroup
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.images.ImageWithCustomSize
@@ -83,6 +86,7 @@ class MapEditorScreen(map: TileMap? = null) : BaseScreen(), RecreateOnResize {
     val tabs: MapEditorMainTabs
     var tileClickHandler: ((tile: Tile)->Unit)? = null
     private var zoomController: ZoomButtonPair? = null
+    val descriptionTextField = UncivTextField.create("Enter a description for the users of this map")
 
     private val highlightedTileGroups = mutableListOf<TileGroup>()
 
@@ -98,10 +102,12 @@ class MapEditorScreen(map: TileMap? = null) : BaseScreen(), RecreateOnResize {
         } else {
             ruleset = map.ruleset ?: RulesetCache.getComplexRuleset(map.mapParameters)
             tileMap = map
+            descriptionTextField.text = map.description
         }
 
         mapHolder = newMapHolder() // will set up ImageGetter and translations, and all dirty flags
         isDirty = false
+        descriptionTextField.onChange { isDirty = true }
 
         tabs = MapEditorMainTabs(this)
         MapEditorToolsDrawer(tabs, stage, mapHolder)
@@ -126,9 +132,8 @@ class MapEditorScreen(map: TileMap? = null) : BaseScreen(), RecreateOnResize {
         }
         fun saveDefaultParameters(parameters: MapParameters) {
             val settings = UncivGame.Current.settings
-            val lastSetup = settings.lastGameSetup
-                ?: GameSetupInfo().also { settings.lastGameSetup = it }
-            lastSetup.mapParameters = parameters.clone()
+            val gameParameters = settings.lastGameSetup?.gameParameters ?: GameParameters()
+            settings.lastGameSetup = GameSetupInfo(gameParameters, parameters)
             settings.save()
         }
     }
@@ -212,6 +217,7 @@ class MapEditorScreen(map: TileMap? = null) : BaseScreen(), RecreateOnResize {
         clearOverlayImages()
         mapHolder.remove()
         tileMap = map
+        descriptionTextField.text = map.description
         ruleset = newRuleset ?: RulesetCache.getComplexRuleset(map.mapParameters)
         mapHolder = newMapHolder()
         isDirty = false
