@@ -178,9 +178,6 @@ class PolicyPickerScreen(
 
         setDefaultCloseAction()
 
-        if (policies.freePolicies > 0 && policies.canAdoptPolicy())
-            closeButton.disable()
-
         rightSideButton.onClick(UncivSound.Policy) {
             confirmAction()
         }
