@@ -26,7 +26,6 @@ import com.unciv.logic.map.MapPathing
 import com.unciv.logic.map.TileMap
 import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.mapunit.movement.UnitMovement
-import com.unciv.logic.map.tile.RoadStatus
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.UncivSound
 import com.unciv.models.UnitActionType
@@ -731,10 +730,9 @@ class WorldMapHolder(
         // Z-Layer: 0
         // Highlight suitable tiles in road connecting mode
         if (worldScreen.bottomUnitTable.selectedUnitIsConnectingRoad) {
-            val roadImprovement = RoadStatus.Road.improvement(unit.currentTile.ruleset)
-            val validTiles = if (roadImprovement==null) listOf()
-            else unit.civ.gameInfo.tileMap.tileList.filter {
-                MapPathing.isValidRoadPathTile(unit, it, roadImprovement)
+            if (unit.currentTile.ruleset.roadImprovement == null) return
+            val validTiles = unit.civ.gameInfo.tileMap.tileList.filter {
+                MapPathing.isValidRoadPathTile(unit, it)
             }
             val connectRoadTileOverlayColor = Color.RED
             for (tile in validTiles)  {
@@ -909,6 +907,20 @@ class WorldMapHolder(
     override fun zoom(zoomScale: Float) {
         super.zoom(zoomScale)
 
+        if (scaleX == minZoom)
+            for (tileGroup in tileGroups.values){
+                val tile = tileGroup.tile
+                if (!worldScreen.selectedCiv.hasExplored(tile)) continue
+                val owner = tile.getOwner()
+                if (owner != null){
+                    val color = if (tile.isCityCenter()) owner.nation.getInnerColor() else owner.nation.getOuterColor()
+                    tileGroup.layerMisc.overlayTerrain(color, 0.7f)
+                }
+            }
+        else
+            for (tileGroup in tileGroups.values)
+                tileGroup.layerMisc.hideTerrainOverlay()
+
         clampCityButtonSize()
     }
 
@@ -961,11 +973,11 @@ class WorldMapHolder(
     }
 
     override fun restrictX(deltaX: Float): Float {
-        val exploredRegion = worldScreen.viewingCiv.exploredRegion
         var result = scrollX - deltaX
+        if (worldScreen.viewingCiv.isSpectator()) return result
 
+        val exploredRegion = worldScreen.viewingCiv.exploredRegion
         if (exploredRegion.shouldRecalculateCoords()) exploredRegion.calculateStageCoords(maxX, maxY)
-
         if (!exploredRegion.shouldRestrictX()) return result
 
         val leftX = exploredRegion.getLeftX()
@@ -980,9 +992,10 @@ class WorldMapHolder(
     }
 
     override fun restrictY(deltaY: Float): Float {
-        val exploredRegion = worldScreen.viewingCiv.exploredRegion
         var result = scrollY + deltaY
+        if (worldScreen.viewingCiv.isSpectator()) return result
 
+        val exploredRegion = worldScreen.viewingCiv.exploredRegion
         if (exploredRegion.shouldRecalculateCoords()) exploredRegion.calculateStageCoords(maxX, maxY)
 
         val topY = exploredRegion.getTopY()
