@@ -5,8 +5,17 @@ import com.badlogic.gdx.utils.Disposable
 
 class StatusButtons(
     nextTurnButton: NextTurnButton,
+    autoPlayStatusButton: AutoPlayStatusButton? = null,
     multiplayerStatusButton: MultiplayerStatusButton? = null
 ) : HorizontalGroup(), Disposable {
+    var autoPlayStatusButton: AutoPlayStatusButton? = autoPlayStatusButton
+        set(button) {
+            autoPlayStatusButton?.remove()
+            field = button
+            if (button != null) {
+                addActorAt(0, button)
+            }
+        }
     var multiplayerStatusButton: MultiplayerStatusButton? = multiplayerStatusButton
         set(button) {
             multiplayerStatusButton?.remove()
@@ -15,10 +24,17 @@ class StatusButtons(
                 addActorAt(0, button)
             }
         }
+    
 
     init {
         space(10f)
         right()
+        wrapReverse()
+        wrapSpace(10f)
+        rowRight()
+        if (autoPlayStatusButton != null) {
+            addActor(autoPlayStatusButton)
+        }
         if (multiplayerStatusButton != null) {
             addActor(multiplayerStatusButton)
         }
@@ -26,6 +42,7 @@ class StatusButtons(
     }
 
     override fun dispose() {
+        autoPlayStatusButton?.dispose()
         multiplayerStatusButton?.dispose()
     }
 }
